@@ -756,117 +756,6 @@ if ( (dvb_debug>=10) && (i%10==0) ) fprintf(stderr, ">>> tuning status == 0x%04x
 /* handle dvb demux                                                        */
 
 
-#if 0
-/* ----------------------------------------------------------------------- */
-void dvb_demux_filter_setup(struct dvb_state *h, int video, int audio)
-{
-	if (dvb_debug>1) _fn_start((char *)__FUNCTION__) ;
-	if (dvb_debug>1) {_prt_indent((char *)__FUNCTION__) ; fprintf(stderr, "video=%d, audio=%d\n", video, audio); }
-
-	h->video.filter.pid      = video;
-    h->video.filter.input    = DMX_IN_FRONTEND;
-    h->video.filter.output   = DMX_OUT_TS_TAP;
-    h->video.filter.pes_type = DMX_PES_VIDEO;
-    h->video.filter.flags    = 0;
-
-    h->audio.filter.pid      = audio;
-    h->audio.filter.input    = DMX_IN_FRONTEND;
-    h->audio.filter.output   = DMX_OUT_TS_TAP;
-    h->audio.filter.pes_type = DMX_PES_AUDIO;
-    h->audio.filter.flags    = 0;
-
-	if (dvb_debug>1) _dump_state((char *)__FUNCTION__, "", h);
-	if (dvb_debug>1) _fn_end((char *)__FUNCTION__, 0) ;
-}
-
-/* ----------------------------------------------------------------------- */
-int dvb_demux_filter_apply(struct dvb_state *h)
-{
-	if (dvb_debug>1) _fn_start((char *)__FUNCTION__) ;
-	if (dvb_debug>1) _dump_state((char *)__FUNCTION__, "", h);
-
-	if (0 != h->video.filter.pid) {
-	/* setup video filter */
-	if (-1 == h->video.fd) {
-	    h->video.fd = open(h->demux,O_RDWR);
-	    if (-1 == h->video.fd) {
-		fprintf(stderr,"dvb mux: [video] open %s: %s\n",
-			h->demux,strerror(errno));
-		goto oops;
-	    }
-	}
-	if (-1 == xioctl(h->video.fd,DMX_SET_PES_FILTER,&h->video.filter,0)) {
-	    fprintf(stderr,"dvb mux: [video] ioctl DMX_SET_PES_FILTER: %s\n",
-		    strerror(errno));
-	    goto oops;
-	}
-    } else {
-	/* no video */
-	if (-1 != h->video.fd) {
-	    close(h->video.fd);
-	    h->video.fd = -1;
-	}
-    }
-
-    if (0 != h->audio.filter.pid) {
-	/* setup audio filter */
-	if (-1 == h->audio.fd) {
-	    h->audio.fd = open(h->demux,O_RDWR);
-	    if (-1 == h->audio.fd) {
-		fprintf(stderr,"dvb mux: [audio] open %s: %s\n",
-			h->demux,strerror(errno));
-		goto oops;
-	    }
-	}
-	if (-1 == xioctl(h->audio.fd,DMX_SET_PES_FILTER,&h->audio.filter,0)) {
-	    fprintf(stderr,"dvb mux: [audio] ioctl DMX_SET_PES_FILTER: %s\n",
-		    strerror(errno));
-	    goto oops;
-	}
-    } else {
-	/* no audio */
-	if (-1 != h->audio.fd) {
-	    close(h->audio.fd);
-	    h->audio.fd = -1;
-	}
-    }
-
-    if (-1 != h->video.fd) {
-	if (-1 == xioctl(h->video.fd,DMX_START,NULL,0)) {
-	    perror("dvb mux: [video] ioctl DMX_START");
-	    goto oops;
-	}
-    }
-    if (-1 != h->audio.fd) {
-	if (-1 == xioctl(h->audio.fd,DMX_START,NULL,0)) {
-	    perror("dvb mux: [audio] ioctl DMX_START");
-	    goto oops;
-	}
-    }
-
-	if (dvb_debug>1) _fn_end((char *)__FUNCTION__, 0) ;
-    return 0;
-
- oops:
-		if (dvb_debug>1) _fn_end((char *)__FUNCTION__, -1) ;
-    return -13;
-}
-
-/* ----------------------------------------------------------------------- */
-void dvb_demux_filter_release(struct dvb_state *h)
-{
-    if (-1 != h->audio.fd) {
-	xioctl(h->audio.fd,DMX_STOP,NULL,0);
-	close(h->audio.fd);
-	h->audio.fd = -1;
-    }
-    if (-1 != h->video.fd) {
-	xioctl(h->video.fd,DMX_STOP,NULL,0);
-	close(h->video.fd);
-	h->video.fd = -1;
-    }
-}
-#endif
 
 
 /* ----------------------------------------------------------------------- */
